from bazel.cc_proto_descriptor_library.testdata import test1_pb2
from bazel.cc_proto_descriptor_library.testdata import test_extension_pb2
from bazel.cc_proto_descriptor_library.testdata import test_pb2
from cel.expr import checked_pb2
from cel.expr import eval_pb2
from cel.expr import explain_pb2
from cel.expr import syntax_pb2
from cel.expr import value_pb2
from cel.expr.conformance import conformance_service_pb2
from cel.expr.conformance import env_config_pb2
from cel.expr.conformance.proto2 import test_all_types_extensions_pb2
from cel.expr.conformance.proto2 import test_all_types_pb2
from cel.expr.conformance.proto3 import test_all_types_pb2
from cel.expr.conformance.test import simple_pb2
from cel.expr.conformance.test import suite_pb2
from contrib.envoy.extensions.compression.qatzip.compressor.v3alpha import qatzip_pb2
from contrib.envoy.extensions.compression.qatzstd.compressor.v3alpha import qatzstd_pb2
from contrib.envoy.extensions.config.v3alpha import kv_store_xds_delegate_config_pb2
from contrib.envoy.extensions.filters.http.checksum.v3alpha import checksum_pb2
from contrib.envoy.extensions.filters.http.dynamo.v3 import dynamo_pb2
from contrib.envoy.extensions.filters.http.golang.v3alpha import golang_pb2
from contrib.envoy.extensions.filters.http.language.v3alpha import language_pb2
from contrib.envoy.extensions.filters.http.peak_ewma.v3alpha import peak_ewma_pb2
from contrib.envoy.extensions.filters.http.sxg.v3alpha import sxg_pb2
from contrib.envoy.extensions.filters.listener.postgres_inspector.v3alpha import postgres_inspector_pb2
from contrib.envoy.extensions.filters.network.client_ssl_auth.v3 import client_ssl_auth_pb2
from contrib.envoy.extensions.filters.network.generic_proxy.codecs.kafka.v3 import kafka_pb2
from contrib.envoy.extensions.filters.network.golang.v3alpha import golang_pb2
from contrib.envoy.extensions.filters.network.kafka_broker.v3 import kafka_broker_pb2
from contrib.envoy.extensions.filters.network.kafka_mesh.v3alpha import kafka_mesh_pb2
from contrib.envoy.extensions.filters.network.mysql_proxy.v3 import mysql_proxy_pb2
from contrib.envoy.extensions.filters.network.postgres_proxy.v3alpha import postgres_proxy_pb2
from contrib.envoy.extensions.filters.network.rocketmq_proxy.v3 import rocketmq_proxy_pb2
from contrib.envoy.extensions.filters.network.rocketmq_proxy.v3 import route_pb2
from contrib.envoy.extensions.filters.network.sip_proxy.router.v3alpha import router_pb2
from contrib.envoy.extensions.filters.network.sip_proxy.tra.v3alpha import tra_pb2
from contrib.envoy.extensions.filters.network.sip_proxy.v3alpha import route_pb2
from contrib.envoy.extensions.filters.network.sip_proxy.v3alpha import sip_proxy_pb2
from contrib.envoy.extensions.load_balancing_policies.peak_ewma.v3alpha import peak_ewma_pb2
from contrib.envoy.extensions.matching.input_matchers.hyperscan.v3alpha import hyperscan_pb2
from contrib.envoy.extensions.network.connection_balance.dlb.v3alpha import dlb_pb2
from contrib.envoy.extensions.private_key_providers.cryptomb.v3alpha import cryptomb_pb2
from contrib.envoy.extensions.private_key_providers.qat.v3alpha import qat_pb2
from contrib.envoy.extensions.regex_engines.hyperscan.v3alpha import hyperscan_pb2
from contrib.envoy.extensions.router.cluster_specifier.golang.v3alpha import golang_pb2
from contrib.envoy.extensions.tap_sinks.udp_sink.v3alpha import udp_sink_pb2
from contrib.envoy.extensions.upstreams.http.tcp.golang.v3alpha import golang_pb2
from contrib.envoy.extensions.vcl.v3alpha import vcl_socket_interface_pb2
from envoy.admin.v2alpha import certs_pb2
from envoy.admin.v2alpha import clusters_pb2
from envoy.admin.v2alpha import config_dump_pb2
from envoy.admin.v2alpha import listeners_pb2
from envoy.admin.v2alpha import memory_pb2
from envoy.admin.v2alpha import metrics_pb2
from envoy.admin.v2alpha import mutex_stats_pb2
from envoy.admin.v2alpha import server_info_pb2
from envoy.admin.v2alpha import tap_pb2
from envoy.admin.v3 import certs_pb2
from envoy.admin.v3 import clusters_pb2
from envoy.admin.v3 import config_dump_pb2
from envoy.admin.v3 import config_dump_shared_pb2
from envoy.admin.v3 import init_dump_pb2
from envoy.admin.v3 import listeners_pb2
from envoy.admin.v3 import memory_pb2
from envoy.admin.v3 import metrics_pb2
from envoy.admin.v3 import mutex_stats_pb2
from envoy.admin.v3 import server_info_pb2
from envoy.admin.v3 import tap_pb2
from envoy.annotations import deprecation_pb2
from envoy.annotations import resource_pb2
from envoy.api.v2 import cds_pb2
from envoy.api.v2 import cluster_pb2
from envoy.api.v2 import discovery_pb2
from envoy.api.v2 import eds_pb2
from envoy.api.v2 import endpoint_pb2
from envoy.api.v2 import lds_pb2
from envoy.api.v2 import listener_pb2
from envoy.api.v2 import rds_pb2
from envoy.api.v2 import route_pb2
from envoy.api.v2 import scoped_route_pb2
from envoy.api.v2 import srds_pb2
from envoy.api.v2.auth import cert_pb2
from envoy.api.v2.auth import common_pb2
from envoy.api.v2.auth import secret_pb2
from envoy.api.v2.auth import tls_pb2
from envoy.api.v2.cluster import circuit_breaker_pb2
from envoy.api.v2.cluster import filter_pb2
from envoy.api.v2.cluster import outlier_detection_pb2
from envoy.api.v2.core import address_pb2
from envoy.api.v2.core import backoff_pb2
from envoy.api.v2.core import base_pb2
from envoy.api.v2.core import config_source_pb2
from envoy.api.v2.core import event_service_config_pb2
from envoy.api.v2.core import grpc_method_list_pb2
from envoy.api.v2.core import grpc_service_pb2
from envoy.api.v2.core import health_check_pb2
from envoy.api.v2.core import http_uri_pb2
from envoy.api.v2.core import protocol_pb2
from envoy.api.v2.core import socket_option_pb2
from envoy.api.v2.endpoint import endpoint_components_pb2
from envoy.api.v2.endpoint import endpoint_pb2
from envoy.api.v2.endpoint import load_report_pb2
from envoy.api.v2.listener import listener_components_pb2
from envoy.api.v2.listener import listener_pb2
from envoy.api.v2.listener import quic_config_pb2
from envoy.api.v2.listener import udp_listener_config_pb2
from envoy.api.v2.ratelimit import ratelimit_pb2
from envoy.api.v2.route import route_components_pb2
from envoy.api.v2.route import route_pb2
from envoy.config.accesslog.v2 import als_pb2
from envoy.config.accesslog.v2 import file_pb2
from envoy.config.accesslog.v3 import accesslog_pb2
from envoy.config.bootstrap.v2 import bootstrap_pb2
from envoy.config.bootstrap.v3 import bootstrap_pb2
from envoy.config.cluster.aggregate.v2alpha import cluster_pb2
from envoy.config.cluster.dynamic_forward_proxy.v2alpha import cluster_pb2
from envoy.config.cluster.redis import redis_cluster_pb2
from envoy.config.cluster.v3 import circuit_breaker_pb2
from envoy.config.cluster.v3 import cluster_pb2
from envoy.config.cluster.v3 import filter_pb2
from envoy.config.cluster.v3 import outlier_detection_pb2
from envoy.config.common.dynamic_forward_proxy.v2alpha import dns_cache_pb2
from envoy.config.common.key_value.v3 import config_pb2
from envoy.config.common.matcher.v3 import matcher_pb2
from envoy.config.common.mutation_rules.v3 import mutation_rules_pb2
from envoy.config.common.tap.v2alpha import common_pb2
from envoy.config.core.v3 import address_pb2
from envoy.config.core.v3 import backoff_pb2
from envoy.config.core.v3 import base_pb2
from envoy.config.core.v3 import cel_pb2
from envoy.config.core.v3 import config_source_pb2
from envoy.config.core.v3 import event_service_config_pb2
from envoy.config.core.v3 import extension_pb2
from envoy.config.core.v3 import grpc_method_list_pb2
from envoy.config.core.v3 import grpc_service_pb2
from envoy.config.core.v3 import health_check_pb2
from envoy.config.core.v3 import http_service_pb2
from envoy.config.core.v3 import http_uri_pb2
from envoy.config.core.v3 import protocol_pb2
from envoy.config.core.v3 import proxy_protocol_pb2
from envoy.config.core.v3 import resolver_pb2
from envoy.config.core.v3 import socket_cmsg_headers_pb2
from envoy.config.core.v3 import socket_option_pb2
from envoy.config.core.v3 import substitution_format_string_pb2
from envoy.config.core.v3 import udp_socket_config_pb2
from envoy.config.endpoint.v3 import endpoint_components_pb2
from envoy.config.endpoint.v3 import endpoint_pb2
from envoy.config.endpoint.v3 import load_report_pb2
from envoy.config.filter.accesslog.v2 import accesslog_pb2
from envoy.config.filter.dubbo.router.v2alpha1 import router_pb2
from envoy.config.filter.fault.v2 import fault_pb2
from envoy.config.filter.http.adaptive_concurrency.v2alpha import adaptive_concurrency_pb2
from envoy.config.filter.http.aws_lambda.v2alpha import aws_lambda_pb2
from envoy.config.filter.http.aws_request_signing.v2alpha import aws_request_signing_pb2
from envoy.config.filter.http.buffer.v2 import buffer_pb2
from envoy.config.filter.http.cache.v2alpha import cache_pb2
from envoy.config.filter.http.compressor.v2 import compressor_pb2
from envoy.config.filter.http.cors.v2 import cors_pb2
from envoy.config.filter.http.csrf.v2 import csrf_pb2
from envoy.config.filter.http.dynamic_forward_proxy.v2alpha import dynamic_forward_proxy_pb2
from envoy.config.filter.http.dynamo.v2 import dynamo_pb2
from envoy.config.filter.http.ext_authz.v2 import ext_authz_pb2
from envoy.config.filter.http.fault.v2 import fault_pb2
from envoy.config.filter.http.grpc_http1_bridge.v2 import config_pb2
from envoy.config.filter.http.grpc_http1_reverse_bridge.v2alpha1 import config_pb2
from envoy.config.filter.http.grpc_stats.v2alpha import config_pb2
from envoy.config.filter.http.grpc_web.v2 import grpc_web_pb2
from envoy.config.filter.http.gzip.v2 import gzip_pb2
from envoy.config.filter.http.header_to_metadata.v2 import header_to_metadata_pb2
from envoy.config.filter.http.health_check.v2 import health_check_pb2
from envoy.config.filter.http.ip_tagging.v2 import ip_tagging_pb2
from envoy.config.filter.http.jwt_authn.v2alpha import config_pb2
from envoy.config.filter.http.lua.v2 import lua_pb2
from envoy.config.filter.http.on_demand.v2 import on_demand_pb2
from envoy.config.filter.http.original_src.v2alpha1 import original_src_pb2
from envoy.config.filter.http.rate_limit.v2 import rate_limit_pb2
from envoy.config.filter.http.rbac.v2 import rbac_pb2
from envoy.config.filter.http.router.v2 import router_pb2
from envoy.config.filter.http.squash.v2 import squash_pb2
from envoy.config.filter.http.tap.v2alpha import tap_pb2
from envoy.config.filter.http.transcoder.v2 import transcoder_pb2
from envoy.config.filter.listener.http_inspector.v2 import http_inspector_pb2
from envoy.config.filter.listener.original_dst.v2 import original_dst_pb2
from envoy.config.filter.listener.original_src.v2alpha1 import original_src_pb2
from envoy.config.filter.listener.proxy_protocol.v2 import proxy_protocol_pb2
from envoy.config.filter.listener.tls_inspector.v2 import tls_inspector_pb2
from envoy.config.filter.network.client_ssl_auth.v2 import client_ssl_auth_pb2
from envoy.config.filter.network.direct_response.v2 import config_pb2
from envoy.config.filter.network.dubbo_proxy.v2alpha1 import dubbo_proxy_pb2
from envoy.config.filter.network.dubbo_proxy.v2alpha1 import route_pb2
from envoy.config.filter.network.echo.v2 import echo_pb2
from envoy.config.filter.network.ext_authz.v2 import ext_authz_pb2
from envoy.config.filter.network.http_connection_manager.v2 import http_connection_manager_pb2
from envoy.config.filter.network.kafka_broker.v2alpha1 import kafka_broker_pb2
from envoy.config.filter.network.local_rate_limit.v2alpha import local_rate_limit_pb2
from envoy.config.filter.network.mongo_proxy.v2 import mongo_proxy_pb2
from envoy.config.filter.network.mysql_proxy.v1alpha1 import mysql_proxy_pb2
from envoy.config.filter.network.rate_limit.v2 import rate_limit_pb2
from envoy.config.filter.network.rbac.v2 import rbac_pb2
from envoy.config.filter.network.redis_proxy.v2 import redis_proxy_pb2
from envoy.config.filter.network.sni_cluster.v2 import sni_cluster_pb2
from envoy.config.filter.network.tcp_proxy.v2 import tcp_proxy_pb2
from envoy.config.filter.network.thrift_proxy.v2alpha1 import route_pb2
from envoy.config.filter.network.thrift_proxy.v2alpha1 import thrift_proxy_pb2
from envoy.config.filter.network.zookeeper_proxy.v1alpha1 import zookeeper_proxy_pb2
from envoy.config.filter.thrift.rate_limit.v2alpha1 import rate_limit_pb2
from envoy.config.filter.thrift.router.v2alpha1 import router_pb2
from envoy.config.filter.udp.udp_proxy.v2alpha import udp_proxy_pb2
from envoy.config.grpc_credential.v2alpha import aws_iam_pb2
from envoy.config.grpc_credential.v2alpha import file_based_metadata_pb2
from envoy.config.grpc_credential.v3 import file_based_metadata_pb2
from envoy.config.health_checker.redis.v2 import redis_pb2
from envoy.config.listener.v2 import api_listener_pb2
from envoy.config.listener.v3 import api_listener_pb2
from envoy.config.listener.v3 import listener_components_pb2
from envoy.config.listener.v3 import listener_pb2
from envoy.config.listener.v3 import quic_config_pb2
from envoy.config.listener.v3 import udp_listener_config_pb2
from envoy.config.metrics.v2 import metrics_service_pb2
from envoy.config.metrics.v2 import stats_pb2
from envoy.config.metrics.v3 import metrics_service_pb2
from envoy.config.metrics.v3 import stats_pb2
from envoy.config.overload.v2alpha import overload_pb2
from envoy.config.overload.v3 import overload_pb2
from envoy.config.ratelimit.v2 import rls_pb2
from envoy.config.ratelimit.v3 import rls_pb2
from envoy.config.rbac.v2 import rbac_pb2
from envoy.config.rbac.v3 import rbac_pb2
from envoy.config.resource_monitor.fixed_heap.v2alpha import fixed_heap_pb2
from envoy.config.resource_monitor.injected_resource.v2alpha import injected_resource_pb2
from envoy.config.retry.omit_canary_hosts.v2 import omit_canary_hosts_pb2
from envoy.config.retry.omit_host_metadata.v2 import omit_host_metadata_config_pb2
from envoy.config.retry.previous_hosts.v2 import previous_hosts_pb2
from envoy.config.retry.previous_priorities import previous_priorities_config_pb2
from envoy.config.route.v3 import route_components_pb2
from envoy.config.route.v3 import route_pb2
from envoy.config.route.v3 import scoped_route_pb2
from envoy.config.tap.v3 import common_pb2
from envoy.config.trace.v2 import datadog_pb2
from envoy.config.trace.v2 import dynamic_ot_pb2
from envoy.config.trace.v2 import http_tracer_pb2
from envoy.config.trace.v2 import lightstep_pb2
from envoy.config.trace.v2 import service_pb2
from envoy.config.trace.v2 import trace_pb2
from envoy.config.trace.v2 import zipkin_pb2
from envoy.config.trace.v2alpha import xray_pb2
from envoy.config.trace.v3 import datadog_pb2
from envoy.config.trace.v3 import dynamic_ot_pb2
from envoy.config.trace.v3 import http_tracer_pb2
from envoy.config.trace.v3 import lightstep_pb2
from envoy.config.trace.v3 import opentelemetry_pb2
from envoy.config.trace.v3 import service_pb2
from envoy.config.trace.v3 import skywalking_pb2
from envoy.config.trace.v3 import trace_pb2
from envoy.config.trace.v3 import xray_pb2
from envoy.config.trace.v3 import zipkin_pb2
from envoy.config.transport_socket.alts.v2alpha import alts_pb2
from envoy.config.transport_socket.raw_buffer.v2 import raw_buffer_pb2
from envoy.config.transport_socket.tap.v2alpha import tap_pb2
from envoy.config.upstream.local_address_selector.v3 import default_local_address_selector_pb2
from envoy.data.accesslog.v2 import accesslog_pb2
from envoy.data.accesslog.v3 import accesslog_pb2
from envoy.data.cluster.v2alpha import outlier_detection_event_pb2
from envoy.data.cluster.v3 import outlier_detection_event_pb2
from envoy.data.core.v2alpha import health_check_event_pb2
from envoy.data.core.v3 import health_check_event_pb2
from envoy.data.core.v3 import tlv_metadata_pb2
from envoy.data.dns.v2alpha import dns_table_pb2
from envoy.data.dns.v3 import dns_table_pb2
from envoy.data.tap.v2alpha import common_pb2
from envoy.data.tap.v2alpha import http_pb2
from envoy.data.tap.v2alpha import transport_pb2
from envoy.data.tap.v2alpha import wrapper_pb2
from envoy.data.tap.v3 import common_pb2
from envoy.data.tap.v3 import http_pb2
from envoy.data.tap.v3 import transport_pb2
from envoy.data.tap.v3 import wrapper_pb2
from envoy.extensions.access_loggers.file.v3 import file_pb2
from envoy.extensions.access_loggers.filters.cel.v3 import cel_pb2
from envoy.extensions.access_loggers.filters.process_ratelimit.v3 import process_ratelimit_pb2
from envoy.extensions.access_loggers.fluentd.v3 import fluentd_pb2
from envoy.extensions.access_loggers.grpc.v3 import als_pb2
from envoy.extensions.access_loggers.open_telemetry.v3 import logs_service_pb2
from envoy.extensions.access_loggers.stats.v3 import stats_pb2
from envoy.extensions.access_loggers.stream.v3 import stream_pb2
from envoy.extensions.access_loggers.wasm.v3 import wasm_pb2
from envoy.extensions.bootstrap.internal_listener.v3 import internal_listener_pb2
from envoy.extensions.bootstrap.reverse_tunnel.downstream_socket_interface.v3 import downstream_reverse_connection_socket_interface_pb2
from envoy.extensions.bootstrap.reverse_tunnel.upstream_socket_interface.v3 import upstream_reverse_connection_socket_interface_pb2
from envoy.extensions.clusters.aggregate.v3 import cluster_pb2
from envoy.extensions.clusters.common.dns.v3 import dns_pb2
from envoy.extensions.clusters.dns.v3 import dns_cluster_pb2
from envoy.extensions.clusters.dynamic_forward_proxy.v3 import cluster_pb2
from envoy.extensions.clusters.redis.v3 import redis_cluster_pb2
from envoy.extensions.clusters.reverse_connection.v3 import reverse_connection_pb2
from envoy.extensions.common.async_files.v3 import async_file_manager_pb2
from envoy.extensions.common.aws.v3 import credential_provider_pb2
from envoy.extensions.common.dynamic_forward_proxy.v3 import dns_cache_pb2
from envoy.extensions.common.matching.v3 import extension_matcher_pb2
from envoy.extensions.common.ratelimit.v3 import ratelimit_pb2
from envoy.extensions.common.tap.v3 import common_pb2
from envoy.extensions.compression.brotli.compressor.v3 import brotli_pb2
from envoy.extensions.compression.brotli.decompressor.v3 import brotli_pb2
from envoy.extensions.compression.gzip.compressor.v3 import gzip_pb2
from envoy.extensions.compression.gzip.decompressor.v3 import gzip_pb2
from envoy.extensions.compression.zstd.compressor.v3 import zstd_pb2
from envoy.extensions.compression.zstd.decompressor.v3 import zstd_pb2
from envoy.extensions.config.validators.minimum_clusters.v3 import minimum_clusters_pb2
from envoy.extensions.dynamic_modules.v3 import dynamic_modules_pb2
from envoy.extensions.early_data.v3 import default_early_data_policy_pb2
from envoy.extensions.filters.common.dependency.v3 import dependency_pb2
from envoy.extensions.filters.common.fault.v3 import fault_pb2
from envoy.extensions.filters.common.matcher.action.v3 import skip_action_pb2
from envoy.extensions.filters.common.set_filter_state.v3 import value_pb2
from envoy.extensions.filters.http.adaptive_concurrency.v3 import adaptive_concurrency_pb2
from envoy.extensions.filters.http.admission_control.v3 import admission_control_pb2
from envoy.extensions.filters.http.alternate_protocols_cache.v3 import alternate_protocols_cache_pb2
from envoy.extensions.filters.http.api_key_auth.v3 import api_key_auth_pb2
from envoy.extensions.filters.http.aws_lambda.v3 import aws_lambda_pb2
from envoy.extensions.filters.http.aws_request_signing.v3 import aws_request_signing_pb2
from envoy.extensions.filters.http.bandwidth_limit.v3 import bandwidth_limit_pb2
from envoy.extensions.filters.http.basic_auth.v3 import basic_auth_pb2
from envoy.extensions.filters.http.buffer.v3 import buffer_pb2
from envoy.extensions.filters.http.cache.v3 import cache_pb2
from envoy.extensions.filters.http.cache_v2.v3 import cache_pb2
from envoy.extensions.filters.http.cdn_loop.v3 import cdn_loop_pb2
from envoy.extensions.filters.http.composite.v3 import composite_pb2
from envoy.extensions.filters.http.compressor.v3 import compressor_pb2
from envoy.extensions.filters.http.connect_grpc_bridge.v3 import config_pb2
from envoy.extensions.filters.http.cors.v3 import cors_pb2
from envoy.extensions.filters.http.credential_injector.v3 import credential_injector_pb2
from envoy.extensions.filters.http.csrf.v3 import csrf_pb2
from envoy.extensions.filters.http.custom_response.v3 import custom_response_pb2
from envoy.extensions.filters.http.decompressor.v3 import decompressor_pb2
from envoy.extensions.filters.http.dynamic_forward_proxy.v3 import dynamic_forward_proxy_pb2
from envoy.extensions.filters.http.dynamic_modules.v3 import dynamic_modules_pb2
from envoy.extensions.filters.http.ext_authz.v3 import ext_authz_pb2
from envoy.extensions.filters.http.ext_proc.v3 import ext_proc_pb2
from envoy.extensions.filters.http.ext_proc.v3 import processing_mode_pb2
from envoy.extensions.filters.http.fault.v3 import fault_pb2
from envoy.extensions.filters.http.file_system_buffer.v3 import file_system_buffer_pb2
from envoy.extensions.filters.http.gcp_authn.v3 import gcp_authn_pb2
from envoy.extensions.filters.http.geoip.v3 import geoip_pb2
from envoy.extensions.filters.http.grpc_field_extraction.v3 import config_pb2
from envoy.extensions.filters.http.grpc_http1_bridge.v3 import config_pb2
from envoy.extensions.filters.http.grpc_http1_reverse_bridge.v3 import config_pb2
from envoy.extensions.filters.http.grpc_json_reverse_transcoder.v3 import transcoder_pb2
from envoy.extensions.filters.http.grpc_json_transcoder.v3 import transcoder_pb2
from envoy.extensions.filters.http.grpc_stats.v3 import config_pb2
from envoy.extensions.filters.http.grpc_web.v3 import grpc_web_pb2
from envoy.extensions.filters.http.gzip.v3 import gzip_pb2
from envoy.extensions.filters.http.header_mutation.v3 import header_mutation_pb2
from envoy.extensions.filters.http.header_to_metadata.v3 import header_to_metadata_pb2
from envoy.extensions.filters.http.health_check.v3 import health_check_pb2
from envoy.extensions.filters.http.ip_tagging.v3 import ip_tagging_pb2
from envoy.extensions.filters.http.json_to_metadata.v3 import json_to_metadata_pb2
from envoy.extensions.filters.http.jwt_authn.v3 import config_pb2
from envoy.extensions.filters.http.kill_request.v3 import kill_request_pb2
from envoy.extensions.filters.http.local_ratelimit.v3 import local_rate_limit_pb2
from envoy.extensions.filters.http.lua.v3 import lua_pb2
from envoy.extensions.filters.http.mcp.v3 import mcp_pb2
from envoy.extensions.filters.http.mcp_router.v3 import mcp_router_pb2
from envoy.extensions.filters.http.oauth2.v3 import oauth_pb2
from envoy.extensions.filters.http.on_demand.v3 import on_demand_pb2
from envoy.extensions.filters.http.original_src.v3 import original_src_pb2
from envoy.extensions.filters.http.proto_api_scrubber.v3 import config_pb2
from envoy.extensions.filters.http.proto_api_scrubber.v3 import matcher_actions_pb2
from envoy.extensions.filters.http.proto_message_extraction.v3 import config_pb2
from envoy.extensions.filters.http.rate_limit_quota.v3 import rate_limit_quota_pb2
from envoy.extensions.filters.http.ratelimit.v3 import rate_limit_pb2
from envoy.extensions.filters.http.rbac.v3 import rbac_pb2
from envoy.extensions.filters.http.router.v3 import router_pb2
from envoy.extensions.filters.http.set_filter_state.v3 import set_filter_state_pb2
from envoy.extensions.filters.http.set_metadata.v3 import set_metadata_pb2
from envoy.extensions.filters.http.stateful_session.v3 import stateful_session_pb2
from envoy.extensions.filters.http.tap.v3 import tap_pb2
from envoy.extensions.filters.http.thrift_to_metadata.v3 import thrift_to_metadata_pb2
from envoy.extensions.filters.http.transform.v3 import transform_pb2
from envoy.extensions.filters.http.upstream_codec.v3 import upstream_codec_pb2
from envoy.extensions.filters.http.wasm.v3 import wasm_pb2
from envoy.extensions.filters.listener.http_inspector.v3 import http_inspector_pb2
from envoy.extensions.filters.listener.local_ratelimit.v3 import local_ratelimit_pb2
from envoy.extensions.filters.listener.original_dst.v3 import original_dst_pb2
from envoy.extensions.filters.listener.original_src.v3 import original_src_pb2
from envoy.extensions.filters.listener.proxy_protocol.v3 import proxy_protocol_pb2
from envoy.extensions.filters.listener.tls_inspector.v3 import tls_inspector_pb2
from envoy.extensions.filters.network.connection_limit.v3 import connection_limit_pb2
from envoy.extensions.filters.network.direct_response.v3 import config_pb2
from envoy.extensions.filters.network.dubbo_proxy.router.v3 import router_pb2
from envoy.extensions.filters.network.dubbo_proxy.v3 import dubbo_proxy_pb2
from envoy.extensions.filters.network.dubbo_proxy.v3 import route_pb2
from envoy.extensions.filters.network.echo.v3 import echo_pb2
from envoy.extensions.filters.network.ext_authz.v3 import ext_authz_pb2
from envoy.extensions.filters.network.ext_proc.v3 import ext_proc_pb2
from envoy.extensions.filters.network.generic_proxy.action.v3 import action_pb2
from envoy.extensions.filters.network.generic_proxy.codecs.dubbo.v3 import dubbo_pb2
from envoy.extensions.filters.network.generic_proxy.codecs.http1.v3 import http1_pb2
from envoy.extensions.filters.network.generic_proxy.matcher.v3 import matcher_pb2
from envoy.extensions.filters.network.generic_proxy.router.v3 import router_pb2
from envoy.extensions.filters.network.generic_proxy.v3 import generic_proxy_pb2
from envoy.extensions.filters.network.generic_proxy.v3 import route_pb2
from envoy.extensions.filters.network.geoip.v3 import geoip_pb2
from envoy.extensions.filters.network.http_connection_manager.v3 import http_connection_manager_pb2
from envoy.extensions.filters.network.local_ratelimit.v3 import local_rate_limit_pb2
from envoy.extensions.filters.network.mongo_proxy.v3 import mongo_proxy_pb2
from envoy.extensions.filters.network.ratelimit.v3 import rate_limit_pb2
from envoy.extensions.filters.network.rbac.v3 import rbac_pb2
from envoy.extensions.filters.network.redis_proxy.v3 import redis_proxy_pb2
from envoy.extensions.filters.network.reverse_tunnel.v3 import reverse_tunnel_pb2
from envoy.extensions.filters.network.set_filter_state.v3 import set_filter_state_pb2
from envoy.extensions.filters.network.sni_cluster.v3 import sni_cluster_pb2
from envoy.extensions.filters.network.sni_dynamic_forward_proxy.v3 import sni_dynamic_forward_proxy_pb2
from envoy.extensions.filters.network.tcp_proxy.v3 import tcp_proxy_pb2
from envoy.extensions.filters.network.thrift_proxy.filters.header_to_metadata.v3 import header_to_metadata_pb2
from envoy.extensions.filters.network.thrift_proxy.filters.payload_to_metadata.v3 import payload_to_metadata_pb2
from envoy.extensions.filters.network.thrift_proxy.filters.ratelimit.v3 import rate_limit_pb2
from envoy.extensions.filters.network.thrift_proxy.router.v3 import router_pb2
from envoy.extensions.filters.network.thrift_proxy.v3 import route_pb2
from envoy.extensions.filters.network.thrift_proxy.v3 import thrift_proxy_pb2
from envoy.extensions.filters.network.wasm.v3 import wasm_pb2
from envoy.extensions.filters.network.zookeeper_proxy.v3 import zookeeper_proxy_pb2
from envoy.extensions.filters.udp.dns_filter.v3 import dns_filter_pb2
from envoy.extensions.filters.udp.udp_proxy.session.dynamic_forward_proxy.v3 import dynamic_forward_proxy_pb2
from envoy.extensions.filters.udp.udp_proxy.session.http_capsule.v3 import http_capsule_pb2
from envoy.extensions.filters.udp.udp_proxy.v3 import route_pb2
from envoy.extensions.filters.udp.udp_proxy.v3 import udp_proxy_pb2
from envoy.extensions.formatter.cel.v3 import cel_pb2
from envoy.extensions.formatter.metadata.v3 import metadata_pb2
from envoy.extensions.formatter.req_without_query.v3 import req_without_query_pb2
from envoy.extensions.geoip_providers.common.v3 import common_pb2
from envoy.extensions.geoip_providers.maxmind.v3 import maxmind_pb2
from envoy.extensions.grpc_service.call_credentials.access_token.v3 import access_token_credentials_pb2
from envoy.extensions.grpc_service.call_credentials.file_based_metadata.v3 import file_based_metadata_credentials_pb2
from envoy.extensions.grpc_service.call_credentials.google_compute_engine.v3 import google_compute_engine_credentials_pb2
from envoy.extensions.grpc_service.call_credentials.google_iam.v3 import google_iam_credentials_pb2
from envoy.extensions.grpc_service.call_credentials.google_refresh_token.v3 import google_refresh_token_credentials_pb2
from envoy.extensions.grpc_service.call_credentials.service_account_jwt_access.v3 import service_account_jwt_access_credentials_pb2
from envoy.extensions.grpc_service.call_credentials.sts_service.v3 import sts_service_credentials_pb2
from envoy.extensions.grpc_service.channel_credentials.google_default.v3 import google_default_credentials_pb2
from envoy.extensions.grpc_service.channel_credentials.insecure.v3 import insecure_credentials_pb2
from envoy.extensions.grpc_service.channel_credentials.local.v3 import local_credentials_pb2
from envoy.extensions.grpc_service.channel_credentials.tls.v3 import tls_credentials_pb2
from envoy.extensions.grpc_service.channel_credentials.xds.v3 import xds_credentials_pb2
from envoy.extensions.health_check.event_sinks.file.v3 import file_pb2
from envoy.extensions.health_checkers.redis.v3 import redis_pb2
from envoy.extensions.health_checkers.thrift.v3 import thrift_pb2
from envoy.extensions.http.cache.file_system_http_cache.v3 import file_system_http_cache_pb2
from envoy.extensions.http.cache.simple_http_cache.v3 import config_pb2
from envoy.extensions.http.cache_v2.file_system_http_cache.v3 import file_system_http_cache_pb2
from envoy.extensions.http.cache_v2.simple_http_cache.v3 import config_pb2
from envoy.extensions.http.custom_response.local_response_policy.v3 import local_response_policy_pb2
from envoy.extensions.http.custom_response.redirect_policy.v3 import redirect_policy_pb2
from envoy.extensions.http.early_header_mutation.header_mutation.v3 import header_mutation_pb2
from envoy.extensions.http.ext_proc.processing_request_modifiers.mapped_attribute_builder.v3 import mapped_attribute_builder_pb2
from envoy.extensions.http.ext_proc.response_processors.save_processing_response.v3 import save_processing_response_pb2
from envoy.extensions.http.header_formatters.preserve_case.v3 import preserve_case_pb2
from envoy.extensions.http.header_validators.envoy_default.v3 import header_validator_pb2
from envoy.extensions.http.injected_credentials.generic.v3 import generic_pb2
from envoy.extensions.http.injected_credentials.oauth2.v3 import oauth2_pb2
from envoy.extensions.http.original_ip_detection.custom_header.v3 import custom_header_pb2
from envoy.extensions.http.original_ip_detection.xff.v3 import xff_pb2
from envoy.extensions.http.stateful_session.cookie.v3 import cookie_pb2
from envoy.extensions.http.stateful_session.envelope.v3 import envelope_pb2
from envoy.extensions.http.stateful_session.header.v3 import header_pb2
from envoy.extensions.internal_redirect.allow_listed_routes.v3 import allow_listed_routes_config_pb2
from envoy.extensions.internal_redirect.previous_routes.v3 import previous_routes_config_pb2
from envoy.extensions.internal_redirect.safe_cross_scheme.v3 import safe_cross_scheme_config_pb2
from envoy.extensions.key_value.file_based.v3 import config_pb2
from envoy.extensions.load_balancing_policies.client_side_weighted_round_robin.v3 import client_side_weighted_round_robin_pb2
from envoy.extensions.load_balancing_policies.cluster_provided.v3 import cluster_provided_pb2
from envoy.extensions.load_balancing_policies.common.v3 import common_pb2
from envoy.extensions.load_balancing_policies.least_request.v3 import least_request_pb2
from envoy.extensions.load_balancing_policies.maglev.v3 import maglev_pb2
from envoy.extensions.load_balancing_policies.override_host.v3 import override_host_pb2
from envoy.extensions.load_balancing_policies.pick_first.v3 import pick_first_pb2
from envoy.extensions.load_balancing_policies.random.v3 import random_pb2
from envoy.extensions.load_balancing_policies.ring_hash.v3 import ring_hash_pb2
from envoy.extensions.load_balancing_policies.round_robin.v3 import round_robin_pb2
from envoy.extensions.load_balancing_policies.subset.v3 import subset_pb2
from envoy.extensions.load_balancing_policies.wrr_locality.v3 import wrr_locality_pb2
from envoy.extensions.local_address_selectors.filter_state_override.v3 import config_pb2
from envoy.extensions.matching.common_inputs.environment_variable.v3 import input_pb2
from envoy.extensions.matching.common_inputs.network.v3 import network_inputs_pb2
from envoy.extensions.matching.common_inputs.ssl.v3 import ssl_inputs_pb2
from envoy.extensions.matching.common_inputs.stats.v3 import stats_pb2
from envoy.extensions.matching.common_inputs.transport_socket.v3 import transport_socket_inputs_pb2
from envoy.extensions.matching.input_matchers.consistent_hashing.v3 import consistent_hashing_pb2
from envoy.extensions.matching.input_matchers.ip.v3 import ip_pb2
from envoy.extensions.matching.input_matchers.metadata.v3 import metadata_pb2
from envoy.extensions.matching.input_matchers.runtime_fraction.v3 import runtime_fraction_pb2
from envoy.extensions.network.dns_resolver.apple.v3 import apple_dns_resolver_pb2
from envoy.extensions.network.dns_resolver.cares.v3 import cares_dns_resolver_pb2
from envoy.extensions.network.dns_resolver.getaddrinfo.v3 import getaddrinfo_dns_resolver_pb2
from envoy.extensions.network.socket_interface.v3 import default_socket_interface_pb2
from envoy.extensions.outlier_detection_monitors.common.v3 import error_types_pb2
from envoy.extensions.outlier_detection_monitors.consecutive_errors.v3 import consecutive_errors_pb2
from envoy.extensions.path.match.uri_template.v3 import uri_template_match_pb2
from envoy.extensions.path.rewrite.uri_template.v3 import uri_template_rewrite_pb2
from envoy.extensions.quic.connection_debug_visitor.quic_stats.v3 import quic_stats_pb2
from envoy.extensions.quic.connection_debug_visitor.v3 import connection_debug_visitor_basic_pb2
from envoy.extensions.quic.connection_id_generator.quic_lb.v3 import quic_lb_pb2
from envoy.extensions.quic.connection_id_generator.v3 import envoy_deterministic_connection_id_generator_pb2
from envoy.extensions.quic.crypto_stream.v3 import crypto_stream_pb2
from envoy.extensions.quic.proof_source.v3 import proof_source_pb2
from envoy.extensions.quic.server_preferred_address.v3 import datasource_pb2
from envoy.extensions.quic.server_preferred_address.v3 import fixed_server_preferred_address_config_pb2
from envoy.extensions.rate_limit_descriptors.expr.v3 import expr_pb2
from envoy.extensions.rbac.audit_loggers.stream.v3 import stream_pb2
from envoy.extensions.rbac.matchers.upstream_ip_port.v3 import upstream_ip_port_matcher_pb2
from envoy.extensions.rbac.principals.mtls_authenticated.v3 import mtls_authenticated_pb2
from envoy.extensions.regex_engines.v3 import google_re2_pb2
from envoy.extensions.request_id.uuid.v3 import uuid_pb2
from envoy.extensions.resource_monitors.cgroup_memory.v3 import cgroup_memory_pb2
from envoy.extensions.resource_monitors.cpu_utilization.v3 import cpu_utilization_pb2
from envoy.extensions.resource_monitors.downstream_connections.v3 import downstream_connections_pb2
from envoy.extensions.resource_monitors.fixed_heap.v3 import fixed_heap_pb2
from envoy.extensions.resource_monitors.injected_resource.v3 import injected_resource_pb2
from envoy.extensions.retry.host.omit_canary_hosts.v3 import omit_canary_hosts_pb2
from envoy.extensions.retry.host.omit_host_metadata.v3 import omit_host_metadata_config_pb2
from envoy.extensions.retry.host.previous_hosts.v3 import previous_hosts_pb2
from envoy.extensions.retry.priority.previous_priorities.v3 import previous_priorities_config_pb2
from envoy.extensions.router.cluster_specifiers.lua.v3 import lua_pb2
from envoy.extensions.router.cluster_specifiers.matcher.v3 import matcher_pb2
from envoy.extensions.stat_sinks.graphite_statsd.v3 import graphite_statsd_pb2
from envoy.extensions.stat_sinks.open_telemetry.v3 import open_telemetry_pb2
from envoy.extensions.stat_sinks.wasm.v3 import wasm_pb2
from envoy.extensions.string_matcher.lua.v3 import lua_pb2
from envoy.extensions.tracers.fluentd.v3 import fluentd_pb2
from envoy.extensions.tracers.opentelemetry.resource_detectors.v3 import dynatrace_resource_detector_pb2
from envoy.extensions.tracers.opentelemetry.resource_detectors.v3 import environment_resource_detector_pb2
from envoy.extensions.tracers.opentelemetry.resource_detectors.v3 import static_config_resource_detector_pb2
from envoy.extensions.tracers.opentelemetry.samplers.v3 import always_on_sampler_pb2
from envoy.extensions.tracers.opentelemetry.samplers.v3 import cel_sampler_pb2
from envoy.extensions.tracers.opentelemetry.samplers.v3 import dynatrace_sampler_pb2
from envoy.extensions.tracers.opentelemetry.samplers.v3 import parent_based_sampler_pb2
from envoy.extensions.tracers.opentelemetry.samplers.v3 import trace_id_ratio_based_sampler_pb2
from envoy.extensions.transport_sockets.alts.v3 import alts_pb2
from envoy.extensions.transport_sockets.http_11_proxy.v3 import upstream_http_11_connect_pb2
from envoy.extensions.transport_sockets.internal_upstream.v3 import internal_upstream_pb2
from envoy.extensions.transport_sockets.proxy_protocol.v3 import upstream_proxy_protocol_pb2
from envoy.extensions.transport_sockets.quic.v3 import quic_transport_pb2
from envoy.extensions.transport_sockets.raw_buffer.v3 import raw_buffer_pb2
from envoy.extensions.transport_sockets.s2a.v3 import s2a_pb2
from envoy.extensions.transport_sockets.starttls.v3 import starttls_pb2
from envoy.extensions.transport_sockets.tap.v3 import tap_pb2
from envoy.extensions.transport_sockets.tcp_stats.v3 import tcp_stats_pb2
from envoy.extensions.transport_sockets.tls.v3 import cert_pb2
from envoy.extensions.transport_sockets.tls.v3 import common_pb2
from envoy.extensions.transport_sockets.tls.v3 import secret_pb2
from envoy.extensions.transport_sockets.tls.v3 import tls_pb2
from envoy.extensions.transport_sockets.tls.v3 import tls_spiffe_validator_config_pb2
from envoy.extensions.udp_packet_writer.v3 import udp_default_writer_factory_pb2
from envoy.extensions.udp_packet_writer.v3 import udp_gso_batch_writer_factory_pb2
from envoy.extensions.upstreams.http.generic.v3 import generic_connection_pool_pb2
from envoy.extensions.upstreams.http.http.v3 import http_connection_pool_pb2
from envoy.extensions.upstreams.http.tcp.v3 import tcp_connection_pool_pb2
from envoy.extensions.upstreams.http.udp.v3 import udp_connection_pool_pb2
from envoy.extensions.upstreams.http.v3 import http_protocol_options_pb2
from envoy.extensions.upstreams.tcp.generic.v3 import generic_connection_pool_pb2
from envoy.extensions.upstreams.tcp.v3 import tcp_protocol_options_pb2
from envoy.extensions.wasm.v3 import wasm_pb2
from envoy.extensions.watchdog.profile_action.v3 import profile_action_pb2
from envoy.service.accesslog.v2 import als_pb2
from envoy.service.accesslog.v2 import als_pb2_grpc
from envoy.service.accesslog.v3 import als_pb2
from envoy.service.accesslog.v3 import als_pb2_grpc
from envoy.service.auth.v2 import attribute_context_pb2
from envoy.service.auth.v2 import attribute_context_pb2_grpc
from envoy.service.auth.v2 import external_auth_pb2
from envoy.service.auth.v2 import external_auth_pb2_grpc
from envoy.service.auth.v2alpha import external_auth_pb2
from envoy.service.auth.v2alpha import external_auth_pb2_grpc
from envoy.service.auth.v3 import attribute_context_pb2
from envoy.service.auth.v3 import attribute_context_pb2_grpc
from envoy.service.auth.v3 import external_auth_pb2
from envoy.service.auth.v3 import external_auth_pb2_grpc
from envoy.service.cluster.v3 import cds_pb2
from envoy.service.cluster.v3 import cds_pb2_grpc
from envoy.service.discovery.v2 import ads_pb2
from envoy.service.discovery.v2 import ads_pb2_grpc
from envoy.service.discovery.v2 import hds_pb2
from envoy.service.discovery.v2 import hds_pb2_grpc
from envoy.service.discovery.v2 import rtds_pb2
from envoy.service.discovery.v2 import rtds_pb2_grpc
from envoy.service.discovery.v2 import sds_pb2
from envoy.service.discovery.v2 import sds_pb2_grpc
from envoy.service.discovery.v3 import ads_pb2
from envoy.service.discovery.v3 import ads_pb2_grpc
from envoy.service.discovery.v3 import discovery_pb2
from envoy.service.discovery.v3 import discovery_pb2_grpc
from envoy.service.endpoint.v3 import eds_pb2
from envoy.service.endpoint.v3 import eds_pb2_grpc
from envoy.service.endpoint.v3 import leds_pb2
from envoy.service.endpoint.v3 import leds_pb2_grpc
from envoy.service.event_reporting.v2alpha import event_reporting_service_pb2
from envoy.service.event_reporting.v2alpha import event_reporting_service_pb2_grpc
from envoy.service.event_reporting.v3 import event_reporting_service_pb2
from envoy.service.event_reporting.v3 import event_reporting_service_pb2_grpc
from envoy.service.ext_proc.v3 import external_processor_pb2
from envoy.service.ext_proc.v3 import external_processor_pb2_grpc
from envoy.service.extension.v3 import config_discovery_pb2
from envoy.service.extension.v3 import config_discovery_pb2_grpc
from envoy.service.health.v3 import hds_pb2
from envoy.service.health.v3 import hds_pb2_grpc
from envoy.service.listener.v3 import lds_pb2
from envoy.service.listener.v3 import lds_pb2_grpc
from envoy.service.load_stats.v2 import lrs_pb2
from envoy.service.load_stats.v2 import lrs_pb2_grpc
from envoy.service.load_stats.v3 import lrs_pb2
from envoy.service.load_stats.v3 import lrs_pb2_grpc
from envoy.service.network_ext_proc.v3 import network_external_processor_pb2
from envoy.service.network_ext_proc.v3 import network_external_processor_pb2_grpc
from envoy.service.rate_limit_quota.v3 import rlqs_pb2
from envoy.service.rate_limit_quota.v3 import rlqs_pb2_grpc
from envoy.service.ratelimit.v2 import rls_pb2
from envoy.service.ratelimit.v2 import rls_pb2_grpc
from envoy.service.ratelimit.v3 import rls_pb2
from envoy.service.ratelimit.v3 import rls_pb2_grpc
from envoy.service.redis_auth.v3 import redis_external_auth_pb2
from envoy.service.redis_auth.v3 import redis_external_auth_pb2_grpc
from envoy.service.route.v3 import rds_pb2
from envoy.service.route.v3 import rds_pb2_grpc
from envoy.service.route.v3 import srds_pb2
from envoy.service.route.v3 import srds_pb2_grpc
from envoy.service.runtime.v3 import rtds_pb2
from envoy.service.runtime.v3 import rtds_pb2_grpc
from envoy.service.secret.v3 import sds_pb2
from envoy.service.secret.v3 import sds_pb2_grpc
from envoy.service.status.v2 import csds_pb2
from envoy.service.status.v2 import csds_pb2_grpc
from envoy.service.status.v3 import csds_pb2
from envoy.service.status.v3 import csds_pb2_grpc
from envoy.service.tap.v2alpha import common_pb2
from envoy.service.tap.v2alpha import common_pb2_grpc
from envoy.service.tap.v2alpha import tap_pb2
from envoy.service.tap.v2alpha import tap_pb2_grpc
from envoy.service.tap.v3 import tap_pb2
from envoy.service.tap.v3 import tap_pb2_grpc
from envoy.type import hash_policy_pb2
from envoy.type import http_pb2
from envoy.type import http_status_pb2
from envoy.type import percent_pb2
from envoy.type import range_pb2
from envoy.type import semantic_version_pb2
from envoy.type import token_bucket_pb2
from envoy.type.http.v3 import cookie_pb2
from envoy.type.http.v3 import path_transformation_pb2
from envoy.type.matcher import metadata_pb2
from envoy.type.matcher import node_pb2
from envoy.type.matcher import number_pb2
from envoy.type.matcher import path_pb2
from envoy.type.matcher import regex_pb2
from envoy.type.matcher import string_pb2
from envoy.type.matcher import struct_pb2
from envoy.type.matcher import value_pb2
from envoy.type.matcher.v3 import address_pb2
from envoy.type.matcher.v3 import filter_state_pb2
from envoy.type.matcher.v3 import http_inputs_pb2
from envoy.type.matcher.v3 import metadata_pb2
from envoy.type.matcher.v3 import node_pb2
from envoy.type.matcher.v3 import number_pb2
from envoy.type.matcher.v3 import path_pb2
from envoy.type.matcher.v3 import regex_pb2
from envoy.type.matcher.v3 import status_code_input_pb2
from envoy.type.matcher.v3 import string_pb2
from envoy.type.matcher.v3 import struct_pb2
from envoy.type.matcher.v3 import value_pb2
from envoy.type.metadata.v2 import metadata_pb2
from envoy.type.metadata.v3 import metadata_pb2
from envoy.type.tracing.v2 import custom_tag_pb2
from envoy.type.tracing.v3 import custom_tag_pb2
from envoy.type.v3 import hash_policy_pb2
from envoy.type.v3 import http_pb2
from envoy.type.v3 import http_status_pb2
from envoy.type.v3 import percent_pb2
from envoy.type.v3 import range_pb2
from envoy.type.v3 import ratelimit_strategy_pb2
from envoy.type.v3 import ratelimit_unit_pb2
from envoy.type.v3 import semantic_version_pb2
from envoy.type.v3 import token_bucket_pb2
from envoy.watchdog.v3 import abort_action_pb2
from google.api import annotations_pb2
from google.api import auth_pb2
from google.api import backend_pb2
from google.api import billing_pb2
from google.api import client_pb2
from google.api import config_change_pb2
from google.api import consumer_pb2
from google.api import context_pb2
from google.api import control_pb2
from google.api import distribution_pb2
from google.api import documentation_pb2
from google.api import endpoint_pb2
from google.api import error_reason_pb2
from google.api import field_behavior_pb2
from google.api import field_info_pb2
from google.api import http_pb2
from google.api import httpbody_pb2
from google.api import label_pb2
from google.api import launch_stage_pb2
from google.api import log_pb2
from google.api import logging_pb2
from google.api import metric_pb2
from google.api import monitored_resource_pb2
from google.api import monitoring_pb2
from google.api import policy_pb2
from google.api import quota_pb2
from google.api import resource_pb2
from google.api import routing_pb2
from google.api import service_pb2
from google.api import source_info_pb2
from google.api import system_parameter_pb2
from google.api import usage_pb2
from google.api import visibility_pb2
from google.api.apikeys.v2 import apikeys_pb2
from google.api.apikeys.v2 import resources_pb2
from google.api.cloudquotas.v1 import cloudquotas_pb2
from google.api.cloudquotas.v1 import resources_pb2
from google.api.cloudquotas.v1beta import cloudquotas_pb2
from google.api.cloudquotas.v1beta import quota_adjuster_settings_pb2
from google.api.cloudquotas.v1beta import resources_pb2
from google.api.expr.conformance.v1alpha1 import conformance_service_pb2
from google.api.expr.v1alpha1 import checked_pb2
from google.api.expr.v1alpha1 import eval_pb2
from google.api.expr.v1alpha1 import explain_pb2
from google.api.expr.v1alpha1 import syntax_pb2
from google.api.expr.v1alpha1 import value_pb2
from google.api.expr.v1beta1 import decl_pb2
from google.api.expr.v1beta1 import eval_pb2
from google.api.expr.v1beta1 import expr_pb2
from google.api.expr.v1beta1 import source_pb2
from google.api.expr.v1beta1 import value_pb2
from google.api.servicecontrol.v1 import check_error_pb2
from google.api.servicecontrol.v1 import distribution_pb2
from google.api.servicecontrol.v1 import http_request_pb2
from google.api.servicecontrol.v1 import log_entry_pb2
from google.api.servicecontrol.v1 import metric_value_pb2
from google.api.servicecontrol.v1 import operation_pb2
from google.api.servicecontrol.v1 import quota_controller_pb2
from google.api.servicecontrol.v1 import service_controller_pb2
from google.api.servicecontrol.v2 import service_controller_pb2
from google.api.servicemanagement.v1 import resources_pb2
from google.api.servicemanagement.v1 import servicemanager_pb2
from google.api.serviceusage.v1 import resources_pb2
from google.api.serviceusage.v1 import serviceusage_pb2
from google.api.serviceusage.v1beta1 import resources_pb2
from google.api.serviceusage.v1beta1 import serviceusage_pb2
from google.logging.type import http_request_pb2
from google.logging.type import log_severity_pb2
from google.logging.v2 import log_entry_pb2
from google.logging.v2 import logging_config_pb2
from google.logging.v2 import logging_metrics_pb2
from google.logging.v2 import logging_pb2
from google.longrunning import operations_pb2
from google.rpc import code_pb2
from google.rpc import error_details_pb2
from google.rpc import http_pb2
from google.rpc import status_pb2
from google.rpc.context import attribute_context_pb2
from google.rpc.context import audit_context_pb2
from google.type import calendar_period_pb2
from google.type import color_pb2
from google.type import date_pb2
from google.type import datetime_pb2
from google.type import dayofweek_pb2
from google.type import decimal_pb2
from google.type import expr_pb2
from google.type import fraction_pb2
from google.type import interval_pb2
from google.type import latlng_pb2
from google.type import localized_text_pb2
from google.type import money_pb2
from google.type import month_pb2
from google.type import phone_number_pb2
from google.type import postal_address_pb2
from google.type import quaternion_pb2
from google.type import timeofday_pb2
from opencensus.proto.agent.common.v1 import common_pb2
from opencensus.proto.agent.metrics.v1 import metrics_service_pb2
from opencensus.proto.agent.trace.v1 import trace_service_pb2
from opencensus.proto.metrics.v1 import metrics_pb2
from opencensus.proto.resource.v1 import resource_pb2
from opencensus.proto.stats.v1 import stats_pb2
from opencensus.proto.trace.v1 import trace_config_pb2
from opencensus.proto.trace.v1 import trace_pb2
from opentelemetry.proto.collector.logs.v1 import logs_service_pb2
from opentelemetry.proto.collector.metrics.v1 import metrics_service_pb2
from opentelemetry.proto.collector.trace.v1 import trace_service_pb2
from opentelemetry.proto.common.v1 import common_pb2
from opentelemetry.proto.logs.v1 import logs_pb2
from opentelemetry.proto.metrics.experimental import metrics_config_service_pb2
from opentelemetry.proto.metrics.v1 import metrics_pb2
from opentelemetry.proto.resource.v1 import resource_pb2
from opentelemetry.proto.trace.v1 import trace_config_pb2
from opentelemetry.proto.trace.v1 import trace_pb2
from udpa.annotations import migrate_pb2
from udpa.annotations import security_pb2
from udpa.annotations import sensitive_pb2
from udpa.annotations import status_pb2
from udpa.annotations import versioning_pb2
from udpa.data.orca.v1 import orca_load_report_pb2
from udpa.service.orca.v1 import orca_pb2
from udpa.type.v1 import typed_struct_pb2
from validate import validate_pb2
from xds.annotations.v3 import migrate_pb2
from xds.annotations.v3 import security_pb2
from xds.annotations.v3 import sensitive_pb2
from xds.annotations.v3 import status_pb2
from xds.annotations.v3 import versioning_pb2
from xds.core.v3 import authority_pb2
from xds.core.v3 import cidr_pb2
from xds.core.v3 import collection_entry_pb2
from xds.core.v3 import context_params_pb2
from xds.core.v3 import extension_pb2
from xds.core.v3 import resource_locator_pb2
from xds.core.v3 import resource_name_pb2
from xds.core.v3 import resource_pb2
from xds.data.orca.v3 import orca_load_report_pb2
from xds.service.orca.v3 import orca_pb2
from xds.type.matcher.v3 import cel_pb2
from xds.type.matcher.v3 import domain_pb2
from xds.type.matcher.v3 import http_inputs_pb2
from xds.type.matcher.v3 import ip_pb2
from xds.type.matcher.v3 import matcher_pb2
from xds.type.matcher.v3 import range_pb2
from xds.type.matcher.v3 import regex_pb2
from xds.type.matcher.v3 import string_pb2
from xds.type.v3 import cel_pb2
from xds.type.v3 import range_pb2
from xds.type.v3 import typed_struct_pb2



# Copyright 2016 gRPC authors.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from concurrent import futures
import threading


class RecordingThreadPool(futures.ThreadPoolExecutor):
    """A thread pool that records if used."""

    def __init__(self, max_workers):
        self._tp_executor = futures.ThreadPoolExecutor(max_workers=max_workers)
        self._lock = threading.Lock()
        self._was_used = False

    def submit(self, fn, *args, **kwargs):  # pylint: disable=arguments-differ
        with self._lock:
            self._was_used = True
        self._tp_executor.submit(fn, *args, **kwargs)

    def was_used(self):
        with self._lock:
            return self._was_used



#!/usr/bin/env python3
# Copyright 2021 The gRPC Authors
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# This script generates a load test configuration template from a collection of
# load test configurations.
#
# Configuration templates contain client and server configurations for multiple
# languages, and may contain template substitution keys. These templates are
# used to generate load test configurations by selecting clients and servers for
# the required languages. The source files for template generation may be load
# test configurations or load test configuration templates. Load test
# configuration generation is performed by loadtest_config.py. See documentation
# below:
# https://github.com/grpc/grpc/blob/master/tools/run_tests/performance/README.md

import argparse
import os
import sys
from typing import Any, Dict, Iterable, List, Mapping, Type

import yaml

sys.path.append(os.path.dirname(os.path.abspath(__file__)))
import loadtest_config

TEMPLATE_FILE_HEADER_COMMENT = """
# Template generated from load test configurations by loadtest_template.py.
#
# Configuration templates contain client and server configurations for multiple
# languages, and may contain template substitution keys. These templates are
# used to generate load test configurations by selecting clients and servers for
# the required languages. The source files for template generation may be load
# test configurations or load test configuration templates. Load test
# configuration generation is performed by loadtest_config.py. See documentation
# below:
# https://github.com/grpc/grpc/blob/master/tools/run_tests/performance/README.md
"""


def insert_worker(
    worker: Dict[str, Any], workers: List[Dict[str, Any]]
) -> None:
    """Inserts client or server into a list, without inserting duplicates."""

    def dump(w):
        return yaml.dump(w, Dumper=yaml.SafeDumper, default_flow_style=False)

    worker_str = dump(worker)
    if any((worker_str == dump(w) for w in workers)):
        return
    workers.append(worker)


def uniquify_workers(workermap: Dict[str, List[Dict[str, Any]]]) -> None:
    """Name workers if there is more than one for the same map key."""
    for workers in list(workermap.values()):
        if len(workers) <= 1:
            continue
        for i, worker in enumerate(workers):
            worker["name"] = str(i)


def loadtest_template(
        input_file_names: Iterable[str],
        metadata: Mapping[str, Any],
        inject_client_pool: bool,
        inject_driver_image: bool,
        inject_driver_pool: bool,
        inject_server_pool: bool,
        inject_big_query_table: bool,
        inject_timeout_seconds: bool,
        inject_ttl_seconds: bool) -> Dict[str, Any]:  # fmt: skip
    """Generates the load test template."""
    spec = dict()  # type: Dict[str, Any]
    clientmap = dict()  # Dict[str, List[Dict[str, Any]]]
    servermap = dict()  # Dict[Str, List[Dict[str, Any]]]
    template = {
        "apiVersion": "e2etest.grpc.io/v1",
        "kind": "LoadTest",
        "metadata": metadata,
    }
    for input_file_name in input_file_names:
        with open(input_file_name) as f:
            input_config = yaml.safe_load(f.read())

            if input_config.get("apiVersion") != template["apiVersion"]:
                raise ValueError(
                    "Unexpected api version in file {}: {}".format(
                        input_file_name, input_config.get("apiVersion")
                    )
                )
            if input_config.get("kind") != template["kind"]:
                raise ValueError(
                    "Unexpected kind in file {}: {}".format(
                        input_file_name, input_config.get("kind")
                    )
                )

            for client in input_config["spec"]["clients"]:
                del client["name"]
                if inject_client_pool:
                    client["pool"] = "${client_pool}"
                if client["language"] not in clientmap:
                    clientmap[client["language"]] = []
                insert_worker(client, clientmap[client["language"]])

            for server in input_config["spec"]["servers"]:
                del server["name"]
                if inject_server_pool:
                    server["pool"] = "${server_pool}"
                if server["language"] not in servermap:
                    servermap[server["language"]] = []
                insert_worker(server, servermap[server["language"]])

            input_spec = input_config["spec"]
            del input_spec["clients"]
            del input_spec["servers"]
            del input_spec["scenariosJSON"]
            spec.update(input_config["spec"])

    uniquify_workers(clientmap)
    uniquify_workers(servermap)

    spec.update(
        {
            "clients": sum(
                (clientmap[language] for language in sorted(clientmap)),
                start=[],
            ),
            "servers": sum(
                (servermap[language] for language in sorted(servermap)),
                start=[],
            ),
        }
    )

    if "driver" not in spec:
        spec["driver"] = {"language": "cxx"}

    driver = spec["driver"]
    if "name" in driver:
        del driver["name"]
    if inject_driver_image:
        if "run" not in driver:
            driver["run"] = [{"name": "main"}]
        driver["run"][0]["image"] = "${driver_image}"
    if inject_driver_pool:
        driver["pool"] = "${driver_pool}"

    if "run" not in driver:
        if inject_driver_pool:
            raise ValueError("Cannot inject driver.pool: missing driver.run.")
        del spec["driver"]

    if inject_big_query_table:
        if "results" not in spec:
            spec["results"] = dict()
        spec["results"]["bigQueryTable"] = "${big_query_table}"
    if inject_timeout_seconds:
        spec["timeoutSeconds"] = "${timeout_seconds}"
    if inject_ttl_seconds:
        spec["ttlSeconds"] = "${ttl_seconds}"

    template["spec"] = spec

    return template


def template_dumper(header_comment: str) -> Type[yaml.SafeDumper]:
    """Returns a custom dumper to dump templates in the expected format."""

    class TemplateDumper(yaml.SafeDumper):
        def expect_stream_start(self):
            super().expect_stream_start()
            if isinstance(self.event, yaml.StreamStartEvent):
                self.write_indent()
                self.write_indicator(header_comment, need_whitespace=False)

    def str_presenter(dumper, data):
        if "\n" in data:
            return dumper.represent_scalar(
                "tag:yaml.org,2002:str", data, style="|"
            )
        return dumper.represent_scalar("tag:yaml.org,2002:str", data)

    TemplateDumper.add_representer(str, str_presenter)

    return TemplateDumper


def main() -> None:
    argp = argparse.ArgumentParser(
        description="Creates a load test config generator template.",
        fromfile_prefix_chars="@",
    )
    argp.add_argument(
        "-i",
        "--inputs",
        action="extend",
        nargs="+",
        type=str,
        help="Input files.",
    )
    argp.add_argument(
        "-o",
        "--output",
        type=str,
        help="Output file. Outputs to stdout if not set.",
    )
    argp.add_argument(
        "--inject_client_pool",
        action="store_true",
        help="Set spec.client(s).pool values to '${client_pool}'.",
    )
    argp.add_argument(
        "--inject_driver_image",
        action="store_true",
        help="Set spec.driver(s).image values to '${driver_image}'.",
    )
    argp.add_argument(
        "--inject_driver_pool",
        action="store_true",
        help="Set spec.driver(s).pool values to '${driver_pool}'.",
    )
    argp.add_argument(
        "--inject_server_pool",
        action="store_true",
        help="Set spec.server(s).pool values to '${server_pool}'.",
    )
    argp.add_argument(
        "--inject_big_query_table",
        action="store_true",
        help="Set spec.results.bigQueryTable to '${big_query_table}'.",
    )
    argp.add_argument(
        "--inject_timeout_seconds",
        action="store_true",
        help="Set spec.timeoutSeconds to '${timeout_seconds}'.",
    )
    argp.add_argument(
        "--inject_ttl_seconds", action="store_true", help="Set timeout "
    )
    argp.add_argument(
        "-n", "--name", default="", type=str, help="metadata.name."
    )
    argp.add_argument(
        "-a",
        "--annotation",
        action="append",
        type=str,
        help="metadata.annotation(s), in the form key=value.",
        dest="annotations",
    )
    args = argp.parse_args()

    annotations = loadtest_config.parse_key_value_args(args.annotations)

    metadata = {"name": args.name}
    if annotations:
        metadata["annotations"] = annotations

    template = loadtest_template(
        input_file_names=args.inputs,
        metadata=metadata,
        inject_client_pool=args.inject_client_pool,
        inject_driver_image=args.inject_driver_image,
        inject_driver_pool=args.inject_driver_pool,
        inject_server_pool=args.inject_server_pool,
        inject_big_query_table=args.inject_big_query_table,
        inject_timeout_seconds=args.inject_timeout_seconds,
        inject_ttl_seconds=args.inject_ttl_seconds,
    )

    with open(args.output, "w") if args.output else sys.stdout as f:
        yaml.dump(
            template,
            stream=f,
            Dumper=template_dumper(TEMPLATE_FILE_HEADER_COMMENT.strip()),
            default_flow_style=False,
        )


if __name__ == "__main__":
    main()



#!/usr/bin/env python3
#
# Copyright 2018 gRPC authors.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import argparse
import glob
import multiprocessing
import os
import shutil
import subprocess
import sys

from parse_link_map import parse_link_map

sys.path.append(
    os.path.join(
        os.path.dirname(sys.argv[0]), "..", "..", "run_tests", "python_utils"
    )
)
import check_on_pr

# Only show diff 1KB or greater
_DIFF_THRESHOLD = 1000

_SIZE_LABELS = ("Core", "ObjC", "BoringSSL", "Protobuf", "Total")

argp = argparse.ArgumentParser(
    description="Binary size diff of gRPC Objective-C sample"
)

argp.add_argument(
    "-d",
    "--diff_base",
    type=str,
    help="Commit or branch to compare the current one to",
)

args = argp.parse_args()


def dir_size(dir):
    total = 0
    for dirpath, dirnames, filenames in os.walk(dir):
        for f in filenames:
            fp = os.path.join(dirpath, f)
            total += os.stat(fp).st_size
    return total


def get_size(where):
    build_dir = "src/objective-c/examples/Sample/Build/Build-%s/" % where
    link_map_filename = "Build/Intermediates.noindex/Sample.build/Release-iphoneos/Sample.build/Sample-LinkMap-normal-arm64.txt"
    # IMPORTANT: order needs to match labels in _SIZE_LABELS
    return parse_link_map(build_dir + link_map_filename)


def build(where):
    subprocess.check_call(["make", "clean"])
    shutil.rmtree(
        "src/objective-c/examples/Sample/Build/Build-%s" % where,
        ignore_errors=True,
    )
    subprocess.check_call(
        (
            "CONFIG=opt EXAMPLE_PATH=src/objective-c/examples/Sample"
            " SCHEME=Sample ./build_one_example.sh"
        ),
        shell=True,
        cwd="src/objective-c/tests",
    )
    os.rename(
        "src/objective-c/examples/Sample/Build/Build",
        "src/objective-c/examples/Sample/Build/Build-%s" % where,
    )


def _render_row(new, label, old):
    """Render row in 3-column output format."""
    try:
        formatted_new = "{:,}".format(int(new))
    except:
        formatted_new = new
    try:
        formatted_old = "{:,}".format(int(old))
    except:
        formatted_old = old
    return "{:>15}{:>15}{:>15}\n".format(formatted_new, label, formatted_old)


def _diff_sign(new, old, diff_threshold=None):
    """Generate diff sign based on values"""
    diff_sign = " "
    if (
        diff_threshold is not None
        and abs(new_size[i] - old_size[i]) >= diff_threshold
    ):
        diff_sign += "!"
    if new > old:
        diff_sign += "(>)"
    elif new < old:
        diff_sign += "(<)"
    else:
        diff_sign += "(=)"
    return diff_sign


text = "Objective-C binary sizes\n"

build("new")
new_size = get_size("new")
old_size = None

if args.diff_base:
    old = "old"
    where_am_i = (
        subprocess.check_output(["git", "rev-parse", "--abbrev-ref", "HEAD"])
        .decode()
        .strip()
    )
    subprocess.check_call(["git", "checkout", "--", "."])
    subprocess.check_call(["git", "checkout", args.diff_base])
    subprocess.check_call(["git", "submodule", "update", "--force"])
    try:
        build("old")
        old_size = get_size("old")
    finally:
        subprocess.check_call(["git", "checkout", "--", "."])
        subprocess.check_call(["git", "checkout", where_am_i])
        subprocess.check_call(["git", "submodule", "update", "--force"])

text += "**********************STATIC******************\n"
text += _render_row("New size", "", "Old size")
if old_size == None:
    for i in range(0, len(_SIZE_LABELS)):
        if i == len(_SIZE_LABELS) - 1:
            # skip line before rendering "Total"
            text += "\n"
        text += _render_row(new_size[i], _SIZE_LABELS[i], "")
else:
    has_diff = False
    # go through all labels but "Total"
    for i in range(0, len(_SIZE_LABELS) - 1):
        if abs(new_size[i] - old_size[i]) >= _DIFF_THRESHOLD:
            has_diff = True
        diff_sign = _diff_sign(
            new_size[i], old_size[i], diff_threshold=_DIFF_THRESHOLD
        )
        text += _render_row(
            new_size[i], _SIZE_LABELS[i] + diff_sign, old_size[i]
        )

    # render the "Total"
    i = len(_SIZE_LABELS) - 1
    diff_sign = _diff_sign(new_size[i], old_size[i])
    # skip line before rendering "Total"
    text += "\n"
    text += _render_row(new_size[i], _SIZE_LABELS[i] + diff_sign, old_size[i])
    if not has_diff:
        text += "\n No significant differences in binary sizes\n"
text += "\n"

print(text)

check_on_pr.check_on_pr("ObjC Binary Size", "```\n%s\n```" % text)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/extensions/filters/http/admission_control/v3/admission_control.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/extensions/filters/http/admission_control/v3/admission_control.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from envoy.type.v3 import range_pb2 as envoy_dot_type_dot_v3_dot_range__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nJenvoy/extensions/filters/http/admission_control/v3/admission_control.proto\x12\x32\x65nvoy.extensions.filters.http.admission_control.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a\x19\x65nvoy/type/v3/range.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x9a\x07\n\x10\x41\x64missionControl\x12\x39\n\x07\x65nabled\x18\x01 \x01(\x0b\x32(.envoy.config.core.v3.RuntimeFeatureFlag\x12p\n\x10success_criteria\x18\x02 \x01(\x0b\x32T.envoy.extensions.filters.http.admission_control.v3.AdmissionControl.SuccessCriteriaH\x00\x12\x32\n\x0fsampling_window\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x37\n\naggression\x18\x04 \x01(\x0b\x32#.envoy.config.core.v3.RuntimeDouble\x12:\n\x0csr_threshold\x18\x05 \x01(\x0b\x32$.envoy.config.core.v3.RuntimePercent\x12:\n\rrps_threshold\x18\x06 \x01(\x0b\x32#.envoy.config.core.v3.RuntimeUInt32\x12G\n\x19max_rejection_probability\x18\x07 \x01(\x0b\x32$.envoy.config.core.v3.RuntimePercent\x1a\x8e\x03\n\x0fSuccessCriteria\x12x\n\rhttp_criteria\x18\x01 \x01(\x0b\x32\x61.envoy.extensions.filters.http.admission_control.v3.AdmissionControl.SuccessCriteria.HttpCriteria\x12x\n\rgrpc_criteria\x18\x02 \x01(\x0b\x32\x61.envoy.extensions.filters.http.admission_control.v3.AdmissionControl.SuccessCriteria.GrpcCriteria\x1aP\n\x0cHttpCriteria\x12@\n\x13http_success_status\x18\x01 \x03(\x0b\x32\x19.envoy.type.v3.Int32RangeB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x1a\x35\n\x0cGrpcCriteria\x12%\n\x13grpc_success_status\x18\x01 \x03(\rB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x42\x1a\n\x13\x65valuation_criteria\x12\x03\xf8\x42\x01\x42\xd2\x01\n@io.envoyproxy.envoy.extensions.filters.http.admission_control.v3B\x15\x41\x64missionControlProtoP\x01Zmgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/admission_control/v3;admission_controlv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.http.admission_control.v3.admission_control_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n@io.envoyproxy.envoy.extensions.filters.http.admission_control.v3B\025AdmissionControlProtoP\001Zmgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/admission_control/v3;admission_controlv3\272\200\310\321\006\002\020\002'
  _globals['_ADMISSIONCONTROL_SUCCESSCRITERIA_HTTPCRITERIA'].fields_by_name['http_success_status']._loaded_options = None
  _globals['_ADMISSIONCONTROL_SUCCESSCRITERIA_HTTPCRITERIA'].fields_by_name['http_success_status']._serialized_options = b'\372B\005\222\001\002\010\001'
  _globals['_ADMISSIONCONTROL_SUCCESSCRITERIA_GRPCCRITERIA'].fields_by_name['grpc_success_status']._loaded_options = None
  _globals['_ADMISSIONCONTROL_SUCCESSCRITERIA_GRPCCRITERIA'].fields_by_name['grpc_success_status']._serialized_options = b'\372B\005\222\001\002\010\001'
  _globals['_ADMISSIONCONTROL'].oneofs_by_name['evaluation_criteria']._loaded_options = None
  _globals['_ADMISSIONCONTROL'].oneofs_by_name['evaluation_criteria']._serialized_options = b'\370B\001'
  _globals['_ADMISSIONCONTROL']._serialized_start=279
  _globals['_ADMISSIONCONTROL']._serialized_end=1201
  _globals['_ADMISSIONCONTROL_SUCCESSCRITERIA']._serialized_start=775
  _globals['_ADMISSIONCONTROL_SUCCESSCRITERIA']._serialized_end=1173
  _globals['_ADMISSIONCONTROL_SUCCESSCRITERIA_HTTPCRITERIA']._serialized_start=1038
  _globals['_ADMISSIONCONTROL_SUCCESSCRITERIA_HTTPCRITERIA']._serialized_end=1118
  _globals['_ADMISSIONCONTROL_SUCCESSCRITERIA_GRPCCRITERIA']._serialized_start=1120
  _globals['_ADMISSIONCONTROL_SUCCESSCRITERIA_GRPCCRITERIA']._serialized_end=1173
# @@protoc_insertion_point(module_scope)



# Copyright 2024 gRPC authors.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Example gRPC server that applies back-pressure on client"""

from concurrent import futures
import logging
import time

import grpc
import helloworld_pb2
import helloworld_pb2_grpc
import helpers

_PORT = "50051"


class Greeter(helloworld_pb2_grpc.GreeterServicer):
    def SayHelloBidiStream(self, request_iterator, unused_context):
        # Delay read on server side to apply back-pressure on client
        time.sleep(5)

        bytes_received = 0

        # Read request from client on every iteration
        for i, request in enumerate(request_iterator, start=1):
            bytes_received += len(request.name)
            if (i % 10) == 0:
                print(
                    f"{helpers.get_current_time()}   "
                    f"Request {i}:   Received {bytes_received} bytes in total"
                )

            # Simulate server "work"
            time.sleep(1)

            # Send a response
            msg = "Hello!"
            yield helloworld_pb2.HelloReply(message=msg)

            if (i % 10) == 0:
                print(
                    f"{helpers.get_current_time()}   "
                    f"Request {i}:   Sent {bytes_received} bytes in total\n"
                )


def serve():
    server = grpc.server(
        futures.ThreadPoolExecutor(max_workers=10),
        # Setting server options to minimal, to allow low number of maximum
        # bytes in the window.
        # `bdp_probe` is set to 0(false) to disable resizing of window
        options=[
            ("grpc.http2.max_frame_size", 16384),
            ("grpc.http2.bdp_probe", 0),
            ("grpc.max_concurrent_streams", 1),
        ],
    )
    helloworld_pb2_grpc.add_GreeterServicer_to_server(Greeter(), server)

    server.add_insecure_port("[::]:" + _PORT)
    server.start()
    print("Server started, listening on " + _PORT)
    server.wait_for_termination()


if __name__ == "__main__":
    logging.basicConfig()
    serve()



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: contrib/envoy/extensions/filters/network/generic_proxy/matcher/v3/matcher.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.type.matcher.v3 import string_pb2 as envoy_dot_type_dot_matcher_dot_v3_dot_string__pb2
from xds.annotations.v3 import status_pb2 as xds_dot_annotations_dot_v3_dot_status__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nOcontrib/envoy/extensions/filters/network/generic_proxy/matcher/v3/matcher.proto\x12\x39\x65nvoy.extensions.filters.network.generic_proxy.matcher.v3\x1a\"envoy/type/matcher/v3/string.proto\x1a\x1fxds/annotations/v3/status.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x13\n\x11ServiceMatchInput\"\x10\n\x0eHostMatchInput\"\x10\n\x0ePathMatchInput\"\x12\n\x10MethodMatchInput\"4\n\x12PropertyMatchInput\x12\x1e\n\rproperty_name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"\x13\n\x11RequestMatchInput\"q\n\x12KeyValueMatchEntry\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x44\n\x0cstring_match\x18\x02 \x01(\x0b\x32$.envoy.type.matcher.v3.StringMatcherB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\"\x91\x02\n\x0eRequestMatcher\x12\x32\n\x04host\x18\x01 \x01(\x0b\x32$.envoy.type.matcher.v3.StringMatcher\x12\x32\n\x04path\x18\x02 \x01(\x0b\x32$.envoy.type.matcher.v3.StringMatcher\x12\x34\n\x06method\x18\x03 \x01(\x0b\x32$.envoy.type.matcher.v3.StringMatcher\x12\x61\n\nproperties\x18\x04 \x03(\x0b\x32M.envoy.extensions.filters.network.generic_proxy.matcher.v3.KeyValueMatchEntryB\xdd\x01\nGio.envoyproxy.envoy.extensions.filters.network.generic_proxy.matcher.v3B\x0cMatcherProtoP\x01Zrgithub.com/envoyproxy/go-control-plane/contrib/envoy/extensions/filters/network/generic_proxy/matcher/v3;matcherv3\xba\x80\xc8\xd1\x06\x02\x10\x02\xd2\xc6\xa4\xe1\x06\x02\x08\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'contrib.envoy.extensions.filters.network.generic_proxy.matcher.v3.matcher_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\nGio.envoyproxy.envoy.extensions.filters.network.generic_proxy.matcher.v3B\014MatcherProtoP\001Zrgithub.com/envoyproxy/go-control-plane/contrib/envoy/extensions/filters/network/generic_proxy/matcher/v3;matcherv3\272\200\310\321\006\002\020\002\322\306\244\341\006\002\010\001'
  _PROPERTYMATCHINPUT.fields_by_name['property_name']._options = None
  _PROPERTYMATCHINPUT.fields_by_name['property_name']._serialized_options = b'\372B\004r\002\020\001'
  _KEYVALUEMATCHENTRY.fields_by_name['name']._options = None
  _KEYVALUEMATCHENTRY.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _KEYVALUEMATCHENTRY.fields_by_name['string_match']._options = None
  _KEYVALUEMATCHENTRY.fields_by_name['string_match']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_SERVICEMATCHINPUT']._serialized_start=267
  _globals['_SERVICEMATCHINPUT']._serialized_end=286
  _globals['_HOSTMATCHINPUT']._serialized_start=288
  _globals['_HOSTMATCHINPUT']._serialized_end=304
  _globals['_PATHMATCHINPUT']._serialized_start=306
  _globals['_PATHMATCHINPUT']._serialized_end=322
  _globals['_METHODMATCHINPUT']._serialized_start=324
  _globals['_METHODMATCHINPUT']._serialized_end=342
  _globals['_PROPERTYMATCHINPUT']._serialized_start=344
  _globals['_PROPERTYMATCHINPUT']._serialized_end=396
  _globals['_REQUESTMATCHINPUT']._serialized_start=398
  _globals['_REQUESTMATCHINPUT']._serialized_end=417
  _globals['_KEYVALUEMATCHENTRY']._serialized_start=419
  _globals['_KEYVALUEMATCHENTRY']._serialized_end=532
  _globals['_REQUESTMATCHER']._serialized_start=535
  _globals['_REQUESTMATCHER']._serialized_end=808
# @@protoc_insertion_point(module_scope)
